Module: RubyYacht
- Defined in:
- lib/ruby_yacht.rb,
lib/ruby_yacht/dsl/app.rb,
lib/ruby_yacht/dsl/dsl.rb,
lib/ruby_yacht/dsl/project.rb,
lib/ruby_yacht/dsl/database.rb,
lib/ruby_yacht/dsl/dns_server.rb,
lib/ruby_yacht/dsl/configuration.rb
Overview
This module groups together all the libraries for this gem.
Defined Under Namespace
Modules: DSL, Runner Classes: App, Configuration, Database, DnsServer, Project
Class Method Summary collapse
-
.configuration ⇒ Object
This method gets the current configuration for the system.
-
.configure(&block) ⇒ Object
This method adds configuration for the system.
Class Method Details
.configuration ⇒ Object
This method gets the current configuration for the system.
52 53 54 |
# File 'lib/ruby_yacht/dsl/configuration.rb', line 52 def self.configuration @configuration ||= Configuration.new end |
.configure(&block) ⇒ Object
This method adds configuration for the system.
If you pass a block to this method, it will be evaluated using the methods in RubyYacht::Configuration::DSL.
Any projects you define in that block will be added to the current list of projects.
46 47 48 49 |
# File 'lib/ruby_yacht/dsl/configuration.rb', line 46 def self.configure(&block) new_configuration = Configuration::DSL.new.run(block).create_object self.configuration.projects += new_configuration.projects end |