Class: RubyYacht::Database

Inherits:
Object
  • Object
show all
Defined in:
lib/ruby_yacht/dsl/database.rb

Overview

This class stores the configuration for a project’s database server.

You can configure a database with RubyYacht::Database::DSL

Defined Under Namespace

Classes: DSL

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#hostObject

The host that the database server is accessed on.



7
8
9
# File 'lib/ruby_yacht/dsl/database.rb', line 7

def host
  @host
end

#nameObject

The name of the database



10
11
12
# File 'lib/ruby_yacht/dsl/database.rb', line 10

def name
  @name
end

#passwordObject

The password we use to connect to the database



16
17
18
# File 'lib/ruby_yacht/dsl/database.rb', line 16

def password
  @password
end

#usernameObject

The username we use to connect to the database



13
14
15
# File 'lib/ruby_yacht/dsl/database.rb', line 13

def username
  @username
end

Instance Method Details

#local?Boolean

Whether the database is running on the same machine as the app servers.

Returns:

  • (Boolean)


19
20
21
# File 'lib/ruby_yacht/dsl/database.rb', line 19

def local?
  host == 'localhost'
end