Class: RubyYacht::Database::DSL
- Inherits:
-
Object
- Object
- RubyYacht::Database::DSL
- Extended by:
- RubyYacht::DSL::Base::ClassMethods
- Includes:
- RubyYacht::DSL::Base
- Defined in:
- lib/ruby_yacht/dsl/database.rb
Overview
This class provides a DSL for configuring a database.
You can access this DSL by calling database within RubyYacht::Project::DSL. It will create a RubyYacht::Database
Instance Method Summary collapse
-
#host ⇒ Object
:method: host You can call ‘host ’db.test.com’‘ to set the database’s host.
-
#password ⇒ Object
:method: password You can call ‘password ’testpass’‘ to tell the apps to connect to the password
testpass. -
#username ⇒ Object
:method: username You can call ‘username ’db-user’‘ to tell the apps to connect to the database under the name
db-user.
Methods included from RubyYacht::DSL::Base::ClassMethods
add_attribute, add_boolean, add_generic_attribute, add_list, add_object, add_object_list, all_attributes, copied_attributes, created_type, creates_object, default_values, required_attributes
Methods included from RubyYacht::DSL::Base
#check_required_attributes, #create_object, #run
Instance Method Details
#host ⇒ Object
:method: host You can call ‘host ’db.test.com’‘ to set the database’s host.
34 |
# File 'lib/ruby_yacht/dsl/database.rb', line 34 add_attribute :host |
#password ⇒ Object
:method: password You can call ‘password ’testpass’‘ to tell the apps to connect to the password testpass.
52 |
# File 'lib/ruby_yacht/dsl/database.rb', line 52 add_attribute :password |
#username ⇒ Object
:method: username You can call ‘username ’db-user’‘ to tell the apps to connect to the database under the name db-user.
46 |
# File 'lib/ruby_yacht/dsl/database.rb', line 46 add_attribute :username |