Class: RubyYacht::Project

Inherits:
Object
  • Object
show all
Defined in:
lib/ruby_yacht/dsl/project.rb

Overview

This class provides a configuration for a project in our system.

A project is a family of apps that communicate with each other and share a database.

Defined Under Namespace

Classes: DSL

Instance Attribute Summary collapse

Instance Attribute Details

#appsObject

The configuration for the apps. Each entry is a RubyYacht::App.



42
43
44
# File 'lib/ruby_yacht/dsl/project.rb', line 42

def apps
  @apps
end

#check_out_locallyObject

Whether we should check out the code on the host machine, rather than keeping it entirely inside the container.



32
33
34
# File 'lib/ruby_yacht/dsl/project.rb', line 32

def check_out_locally
  @check_out_locally
end

#create_deploy_containerObject

Whether we should create a special container with all the apps for running deploys.



36
37
38
# File 'lib/ruby_yacht/dsl/project.rb', line 36

def create_deploy_container
  @create_deploy_container
end

#databaseObject

The configuration for the database. This is a RubyYacht::Database.



39
40
41
# File 'lib/ruby_yacht/dsl/project.rb', line 39

def database
  @database
end

#dns_serverObject

The configuration for the DNS for the apps. This is a RubyYacht::DnsServer.



45
46
47
# File 'lib/ruby_yacht/dsl/project.rb', line 45

def dns_server
  @dns_server
end

#domainObject

The domain that the apps for this project are accessed under.



19
20
21
# File 'lib/ruby_yacht/dsl/project.rb', line 19

def domain
  @domain
end

#nameObject

The name of the project.



12
13
14
# File 'lib/ruby_yacht/dsl/project.rb', line 12

def name
  @name
end

#rails_environmentObject

The environment that the apps should run in.



28
29
30
# File 'lib/ruby_yacht/dsl/project.rb', line 28

def rails_environment
  @rails_environment
end

#repositoryObject

The hostname for the repository that contains the code for the apps.



22
23
24
# File 'lib/ruby_yacht/dsl/project.rb', line 22

def repository
  @repository
end

#secret_key_baseObject

The secret key that the apps should use for signing cookies.



25
26
27
# File 'lib/ruby_yacht/dsl/project.rb', line 25

def secret_key_base
  @secret_key_base
end

#system_prefixObject

The prefix that we use before all of the images and containers for the project.



16
17
18
# File 'lib/ruby_yacht/dsl/project.rb', line 16

def system_prefix
  @system_prefix
end