Class: RubyYacht::Project

Inherits:
Object
  • Object
show all
Defined in:
lib/ruby_yacht/dsl/project.rb

Overview

This class provides a configuration for a project in our system.

A project is a family of apps that communicate with each other and share a database.

Defined Under Namespace

Classes: DSL

Instance Attribute Summary collapse

Instance Attribute Details

#appsObject

The configuration for the apps. Each entry is a RubyYacht::App.



38
39
40
# File 'lib/ruby_yacht/dsl/project.rb', line 38

def apps
  @apps
end

#check_out_locallyObject

Whether we should check out the code on the host machine, rather than keeping it entirely inside the container.



28
29
30
# File 'lib/ruby_yacht/dsl/project.rb', line 28

def check_out_locally
  @check_out_locally
end

#create_deploy_containerObject

Whether we should create a special container with all the apps for running deploys.



32
33
34
# File 'lib/ruby_yacht/dsl/project.rb', line 32

def create_deploy_container
  @create_deploy_container
end

#databaseObject

The configuration for the database. This is a RubyYacht::Database.



35
36
37
# File 'lib/ruby_yacht/dsl/project.rb', line 35

def database
  @database
end

#dns_serverObject

The configuration for the DNS for the apps. This is a RubyYacht::DnsServer.



41
42
43
# File 'lib/ruby_yacht/dsl/project.rb', line 41

def dns_server
  @dns_server
end

#domainObject

The domain that the apps for this project are accessed under.



15
16
17
# File 'lib/ruby_yacht/dsl/project.rb', line 15

def domain
  @domain
end

#nameObject

The name of the project.



8
9
10
# File 'lib/ruby_yacht/dsl/project.rb', line 8

def name
  @name
end

#rails_environmentObject

The environment that the apps should run in.



24
25
26
# File 'lib/ruby_yacht/dsl/project.rb', line 24

def rails_environment
  @rails_environment
end

#repositoryObject

The hostname for the repository that contains the code for the apps.



18
19
20
# File 'lib/ruby_yacht/dsl/project.rb', line 18

def repository
  @repository
end

#secret_key_baseObject

The secret key that the apps should use for signing cookies.



21
22
23
# File 'lib/ruby_yacht/dsl/project.rb', line 21

def secret_key_base
  @secret_key_base
end

#system_prefixObject

The prefix that we use before all of the images and containers for the project.



12
13
14
# File 'lib/ruby_yacht/dsl/project.rb', line 12

def system_prefix
  @system_prefix
end