Class: RubyYacht::Project
- Inherits:
-
Object
- Object
- RubyYacht::Project
- Defined in:
- lib/ruby_yacht/dsl/project.rb
Overview
This class provides a configuration for a project in our system.
A project is a family of apps that communicate with each other and share a database.
Defined Under Namespace
Classes: DSL
Instance Attribute Summary collapse
-
#apps ⇒ Object
The configuration for the apps.
-
#check_out_locally ⇒ Object
Whether we should check out the code on the host machine, rather than keeping it entirely inside the container.
-
#create_deploy_container ⇒ Object
Whether we should create a special container with all the apps for running deploys.
-
#database ⇒ Object
The configuration for the database.
-
#dns_server ⇒ Object
The configuration for the DNS for the apps.
-
#domain ⇒ Object
The domain that the apps for this project are accessed under.
-
#name ⇒ Object
The name of the project.
-
#rails_environment ⇒ Object
The environment that the apps should run in.
-
#repository ⇒ Object
The hostname for the repository that contains the code for the apps.
-
#secret_key_base ⇒ Object
The secret key that the apps should use for signing cookies.
-
#system_prefix ⇒ Object
The prefix that we use before all of the images and containers for the project.
Instance Attribute Details
#apps ⇒ Object
The configuration for the apps. Each entry is a RubyYacht::App.
38 39 40 |
# File 'lib/ruby_yacht/dsl/project.rb', line 38 def apps @apps end |
#check_out_locally ⇒ Object
Whether we should check out the code on the host machine, rather than keeping it entirely inside the container.
28 29 30 |
# File 'lib/ruby_yacht/dsl/project.rb', line 28 def check_out_locally @check_out_locally end |
#create_deploy_container ⇒ Object
Whether we should create a special container with all the apps for running deploys.
32 33 34 |
# File 'lib/ruby_yacht/dsl/project.rb', line 32 def create_deploy_container @create_deploy_container end |
#database ⇒ Object
The configuration for the database. This is a RubyYacht::Database.
35 36 37 |
# File 'lib/ruby_yacht/dsl/project.rb', line 35 def database @database end |
#dns_server ⇒ Object
The configuration for the DNS for the apps. This is a RubyYacht::DnsServer.
41 42 43 |
# File 'lib/ruby_yacht/dsl/project.rb', line 41 def dns_server @dns_server end |
#domain ⇒ Object
The domain that the apps for this project are accessed under.
15 16 17 |
# File 'lib/ruby_yacht/dsl/project.rb', line 15 def domain @domain end |
#name ⇒ Object
The name of the project.
8 9 10 |
# File 'lib/ruby_yacht/dsl/project.rb', line 8 def name @name end |
#rails_environment ⇒ Object
The environment that the apps should run in.
24 25 26 |
# File 'lib/ruby_yacht/dsl/project.rb', line 24 def rails_environment @rails_environment end |
#repository ⇒ Object
The hostname for the repository that contains the code for the apps.
18 19 20 |
# File 'lib/ruby_yacht/dsl/project.rb', line 18 def repository @repository end |
#secret_key_base ⇒ Object
The secret key that the apps should use for signing cookies.
21 22 23 |
# File 'lib/ruby_yacht/dsl/project.rb', line 21 def secret_key_base @secret_key_base end |
#system_prefix ⇒ Object
The prefix that we use before all of the images and containers for the project.
12 13 14 |
# File 'lib/ruby_yacht/dsl/project.rb', line 12 def system_prefix @system_prefix end |